searchData={"items":[{"type":"module","title":"QMI","doc":"Qualcomm MSM Interface in Elixir\n\nThis module lets you send and receive messages from a QMI-enabled cellular\nmodem.\n\nTo use it, start a `QMI.Supervisor` in the supervision tree of your choosing\nand pass it a name and interface. After that, use the service modules to send\nit messages. For example:\n\n```elixir\n# In your application's supervision tree\nchildren = [\n  #... other children ...\n  {QMI.Supervisor, ifname: \"wwan0\", name: MyApp.QMI}\n  #... other children ...\n]\n\n# Later on\niex> QMI.WirelessData.start_network_interface(MyApp.QMI, apn: \"super\")\n:ok\n\niex> QMI.NetworkAccess.get_signal_strength(MyApp.QMI)\n{:ok, %{rssi_reports: [%{radio: :lte, rssi: -74}]}}\n```","ref":"QMI.html"},{"type":"function","title":"QMI.call/2","doc":"Send a request over QMI and return the response\n\nNOTE: the QMI name parameter is second to facilitate piping","ref":"QMI.html#call/2"},{"type":"function","title":"QMI.configure_linux/1","doc":"Configure the framing when using linux\n\nThis should be called once the device appears and before an attempt is made to\nconnect to the network.","ref":"QMI.html#configure_linux/1"},{"type":"type","title":"QMI.indication_callback_fun/0","doc":"A function that is ran when QMI receives an indication\n\nThis function receives a map as the indication and returns `:ok`.","ref":"QMI.html#t:indication_callback_fun/0"},{"type":"type","title":"QMI.name/0","doc":"The name passed to QMI.Supervisor","ref":"QMI.html#t:name/0"},{"type":"type","title":"QMI.request/0","doc":"Structure that contains information about how to handle a QMI service message\n\n* `:service_id` - which service this request is for\n* `:payload` - iodata of the message being sent\n* `:decode` - a function that will be used to decode the incoming response","ref":"QMI.html#t:request/0"},{"type":"module","title":"QMI.Codec.UserIdentity","doc":"Codec for making user identity service requests","ref":"QMI.Codec.UserIdentity.html"},{"type":"function","title":"QMI.Codec.UserIdentity.read_transparent/2","doc":"Read any transparent file in the card and access by path","ref":"QMI.Codec.UserIdentity.html#read_transparent/2"},{"type":"type","title":"QMI.Codec.UserIdentity.read_transparent_response/0","doc":"The response from issuing a read transparent request","ref":"QMI.Codec.UserIdentity.html#t:read_transparent_response/0"},{"type":"module","title":"QMI.Supervisor","doc":"Main supervisor for QMI processes","ref":"QMI.Supervisor.html"},{"type":"function","title":"QMI.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"QMI.Supervisor.html#child_spec/1"},{"type":"function","title":"QMI.Supervisor.start_link/1","doc":"Start the supervisor\n\nThe `:name` option is required and will be the QMI supervisor process. Pass\nthis name to all functions that have a `qmi` parameter.","ref":"QMI.Supervisor.html#start_link/1"},{"type":"type","title":"QMI.Supervisor.options/0","doc":"QMI Supervisor options\n\n* `:ifname` - the network interface name. i.e. `\"wwan0\"`\n* `:device_path` - the path to the QMI control device. Defaults to `\"/dev/cdc-wdm \"`\nwhere `index` matches the `ifname` index.\n* `:name` - an optional name for this GenServer\n* `:indication_callback` - a function that is ran when an indication is\nreceived from QMI.","ref":"QMI.Supervisor.html#t:options/0"},{"type":"module","title":"QMI.UserIdentity","doc":"Provides commands related to the user identity service","ref":"QMI.UserIdentity.html"},{"type":"function","title":"QMI.UserIdentity.parse_iccid/1","doc":"Parse a raw binary ICCID\n\nCall `read_transparent/3` to get the raw binary CCID.\n\n#","ref":"QMI.UserIdentity.html#parse_iccid/1"},{"type":"function","title":"Examples - QMI.UserIdentity.parse_iccid/1","doc":"iex> raw_binary =  >\n   iex> QMI.UserIdentity.parse_iccid(raw_binary)\n   \"46373040000001250702\"","ref":"QMI.UserIdentity.html#parse_iccid/1-examples"},{"type":"function","title":"QMI.UserIdentity.read_transparent/3","doc":"Send a request to read a transparent file","ref":"QMI.UserIdentity.html#read_transparent/3"},{"type":"module","title":"QMI.Control","doc":"Provides commands related to QMUX link and client management","ref":"QMI.Control.html"},{"type":"function","title":"QMI.Control.get_client_id/2","doc":"Get a client id for a service","ref":"QMI.Control.html#get_client_id/2"},{"type":"function","title":"QMI.Control.release_client_id/3","doc":"Release a client id for a service","ref":"QMI.Control.html#release_client_id/3"},{"type":"module","title":"QMI.DeviceManagement","doc":"Device Management service requests","ref":"QMI.DeviceManagement.html"},{"type":"function","title":"QMI.DeviceManagement.get_firmware_rev/1","doc":"Get the firmware information","ref":"QMI.DeviceManagement.html#get_firmware_rev/1"},{"type":"function","title":"QMI.DeviceManagement.get_hardware_rev/1","doc":"Get the hardware information","ref":"QMI.DeviceManagement.html#get_hardware_rev/1"},{"type":"function","title":"QMI.DeviceManagement.get_manufacturer/1","doc":"Get the device manufacturer information","ref":"QMI.DeviceManagement.html#get_manufacturer/1"},{"type":"function","title":"QMI.DeviceManagement.get_model/1","doc":"Get the device model information","ref":"QMI.DeviceManagement.html#get_model/1"},{"type":"function","title":"QMI.DeviceManagement.get_operating_mode/1","doc":"Get the operating mode","ref":"QMI.DeviceManagement.html#get_operating_mode/1"},{"type":"function","title":"QMI.DeviceManagement.get_serial_numbers/1","doc":"Get the device serial numbers","ref":"QMI.DeviceManagement.html#get_serial_numbers/1"},{"type":"function","title":"QMI.DeviceManagement.set_operating_mode/2","doc":"Set the operating mode","ref":"QMI.DeviceManagement.html#set_operating_mode/2"},{"type":"module","title":"QMI.NetworkAccess","doc":"Provides commands related to network access","ref":"QMI.NetworkAccess.html"},{"type":"function","title":"QMI.NetworkAccess.get_home_network/1","doc":"Get the home network of the device\n\nThis returns the MCC, MNC, and service provider for the network.","ref":"QMI.NetworkAccess.html#get_home_network/1"},{"type":"function","title":"QMI.NetworkAccess.get_rf_band_info/1","doc":"","ref":"QMI.NetworkAccess.html#get_rf_band_info/1"},{"type":"function","title":"QMI.NetworkAccess.get_signal_strength/1","doc":"Get the current signal strength","ref":"QMI.NetworkAccess.html#get_signal_strength/1"},{"type":"function","title":"QMI.NetworkAccess.get_system_selection_preference/1","doc":"Get the system selection preferences","ref":"QMI.NetworkAccess.html#get_system_selection_preference/1"},{"type":"function","title":"QMI.NetworkAccess.set_system_selection_preference/2","doc":"Set the system selection preferences","ref":"QMI.NetworkAccess.html#set_system_selection_preference/2"},{"type":"module","title":"QMI.WirelessData","doc":"Provides command related to wireless messaging","ref":"QMI.WirelessData.html"},{"type":"function","title":"QMI.WirelessData.modify_profile_settings/3","doc":"Modify a profile's settings to be used when starting an interface connection","ref":"QMI.WirelessData.html#modify_profile_settings/3"},{"type":"function","title":"QMI.WirelessData.set_event_report/2","doc":"Set the event report options for the wireless data event indication","ref":"QMI.WirelessData.html#set_event_report/2"},{"type":"function","title":"QMI.WirelessData.start_network_interface/2","doc":"Start the network interface\n\nThis will return once a packet data session is established and the interface\ncan perform IP address configuration. That means once this returns you can\nconfigure the interface via DHCP.","ref":"QMI.WirelessData.html#start_network_interface/2"},{"type":"module","title":"QMI.Codec.Control","doc":"Codec for making control service requests","ref":"QMI.Codec.Control.html"},{"type":"function","title":"QMI.Codec.Control.get_client_id/1","doc":"Request for getting a client id","ref":"QMI.Codec.Control.html#get_client_id/1"},{"type":"function","title":"QMI.Codec.Control.parse_indication/1","doc":"Parse indications for the the control service","ref":"QMI.Codec.Control.html#parse_indication/1"},{"type":"function","title":"QMI.Codec.Control.release_client_id/2","doc":"Release a client id","ref":"QMI.Codec.Control.html#release_client_id/2"},{"type":"type","title":"QMI.Codec.Control.sync_indication/0","doc":"","ref":"QMI.Codec.Control.html#t:sync_indication/0"},{"type":"module","title":"QMI.Codec.DeviceManagement","doc":"Codec for making device management requests","ref":"QMI.Codec.DeviceManagement.html"},{"type":"function","title":"QMI.Codec.DeviceManagement.get_device_hardware_rev/0","doc":"Get the device hardware revision","ref":"QMI.Codec.DeviceManagement.html#get_device_hardware_rev/0"},{"type":"function","title":"QMI.Codec.DeviceManagement.get_device_mfr/0","doc":"Get the device manufacturer","ref":"QMI.Codec.DeviceManagement.html#get_device_mfr/0"},{"type":"function","title":"QMI.Codec.DeviceManagement.get_device_model_id/0","doc":"Get the device model","ref":"QMI.Codec.DeviceManagement.html#get_device_model_id/0"},{"type":"function","title":"QMI.Codec.DeviceManagement.get_device_rev_id/0","doc":"Get the firmware revision id","ref":"QMI.Codec.DeviceManagement.html#get_device_rev_id/0"},{"type":"function","title":"QMI.Codec.DeviceManagement.get_device_serial_numbers/0","doc":"Request for the serial numbers of the device","ref":"QMI.Codec.DeviceManagement.html#get_device_serial_numbers/0"},{"type":"function","title":"QMI.Codec.DeviceManagement.get_operating_mode/0","doc":"Get the operating mode of a device","ref":"QMI.Codec.DeviceManagement.html#get_operating_mode/0"},{"type":"function","title":"QMI.Codec.DeviceManagement.set_operating_mode/1","doc":"Set operating mode of the device","ref":"QMI.Codec.DeviceManagement.html#set_operating_mode/1"},{"type":"type","title":"QMI.Codec.DeviceManagement.offline_reason/0","doc":"","ref":"QMI.Codec.DeviceManagement.html#t:offline_reason/0"},{"type":"type","title":"QMI.Codec.DeviceManagement.operating_mode/0","doc":"","ref":"QMI.Codec.DeviceManagement.html#t:operating_mode/0"},{"type":"type","title":"QMI.Codec.DeviceManagement.operating_mode_response/0","doc":"","ref":"QMI.Codec.DeviceManagement.html#t:operating_mode_response/0"},{"type":"type","title":"QMI.Codec.DeviceManagement.serial_numbers/0","doc":"The serial numbers assigned to the device\n\n  * `esn` - for 3GPP2 devices\n  * `imei` - for 3GPP devices\n  * `meid` - for 3GPP and 3GPP2 devices\n  * `imeisv_svn` - for 3GPP devices","ref":"QMI.Codec.DeviceManagement.html#t:serial_numbers/0"},{"type":"module","title":"QMI.Codec.NetworkAccess","doc":"Codec for making network access service requests","ref":"QMI.Codec.NetworkAccess.html"},{"type":"function","title":"QMI.Codec.NetworkAccess.get_home_network/0","doc":"Make the request for getting the home network","ref":"QMI.Codec.NetworkAccess.html#get_home_network/0"},{"type":"function","title":"QMI.Codec.NetworkAccess.get_rf_band_info/0","doc":"Get the radio band information","ref":"QMI.Codec.NetworkAccess.html#get_rf_band_info/0"},{"type":"function","title":"QMI.Codec.NetworkAccess.get_signal_strength/0","doc":"Make the `QMI.request()` for getting signal strength","ref":"QMI.Codec.NetworkAccess.html#get_signal_strength/0"},{"type":"function","title":"QMI.Codec.NetworkAccess.get_system_selection_preference/0","doc":"Make `QMI.request()` to get the system selection preferences","ref":"QMI.Codec.NetworkAccess.html#get_system_selection_preference/0"},{"type":"function","title":"QMI.Codec.NetworkAccess.parse_indication/1","doc":"Parse an indication","ref":"QMI.Codec.NetworkAccess.html#parse_indication/1"},{"type":"function","title":"QMI.Codec.NetworkAccess.set_system_selection_preference/1","doc":"Generate the `QMI.request()` for setting system selection preferences","ref":"QMI.Codec.NetworkAccess.html#set_system_selection_preference/1"},{"type":"type","title":"QMI.Codec.NetworkAccess.attach_state/0","doc":"","ref":"QMI.Codec.NetworkAccess.html#t:attach_state/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.get_system_selection_preference_response/0","doc":"Preference settings for when a device selects a system\n\n* `:emergency_mode` - `:on` if the device is in emergency mode, `:off`\n  otherwise\n* `:mode_preference` - a list of radio access technologies the device will\n  try to use\n* `:roaming_preference` - the device roaming preference\n* `:network_selection_preference` - if the device will automatically select\n  a network\n* `:acquisition_order` - the order in which the device will try to connect\n  to a radio access technology\n* `:registration_restriction` - the system registration restriction\n* `:usage_settings` - the modem usage preference\n* `:voice_domain_preference` - the voice domain preference","ref":"QMI.Codec.NetworkAccess.html#t:get_system_selection_preference_response/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.home_network_report/0","doc":"Report from requesting the home network","ref":"QMI.Codec.NetworkAccess.html#t:home_network_report/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.network/0","doc":"","ref":"QMI.Codec.NetworkAccess.html#t:network/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.network_selection_preference/0","doc":"The networking selection preference\n\n* `:automatic` - automatically select the network\n* `:manual` - manually select the network","ref":"QMI.Codec.NetworkAccess.html#t:network_selection_preference/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.operator_name_indication/0","doc":"","ref":"QMI.Codec.NetworkAccess.html#t:operator_name_indication/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.preference_change_duration/0","doc":"How long a system preference change should be applied\n\n* `:power_cycle` - only remains active until the next power cycle\n* `:permanent` - remains active through power cycles until changed by a client","ref":"QMI.Codec.NetworkAccess.html#t:preference_change_duration/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.radio_interface/0","doc":"The radio interface that is being reported","ref":"QMI.Codec.NetworkAccess.html#t:radio_interface/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.registration_restriction_preference/0","doc":"The network registration restriction preference\n\n* `:unrestricted` - device follows the normal registration process\n* `:camped_only` - device will camp on a network but not register\n* `:limited` - device selects the network for limited service\n\nThis can also be integer value that is specified by the specific modem\nprovider","ref":"QMI.Codec.NetworkAccess.html#t:registration_restriction_preference/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.rf_band_information/0","doc":"Information about an radio interface band","ref":"QMI.Codec.NetworkAccess.html#t:rf_band_information/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.roaming_preference/0","doc":"The roaming preference\n\n* `:off` - acquire only systems for which the roaming indicator is off\n* `:not_off` - acquire a system as long as its roaming indicator is not off\n* `:not_flashing` - acquire a system as for which the roaming indicator is\n  off or solid on - CDMA only.\n* `:any` - acquire systems, regardless of their roaming indicator","ref":"QMI.Codec.NetworkAccess.html#t:roaming_preference/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.serving_system_indication/0","doc":"Required fields:\n\n* `:name` - the name of the indication\n* `:service_id` - the service id\n* `:indication_id` - the indication id\n* `:serving_system_registration_state` - the state of the registration status\n  to the serving system\n* `:serving_system_cs_attach_state` - the circuit-switched domain attach state\n* `:serving_system_ps_attach_state` - the packet-switched domain attach state\n* `:serving_system_selected_network` - the type of selected radio access network\n* `:serving_system_radio_interfaces` - a list of radio interfaces currently in use\n\nOptional fields:\n\n* `:cell_id` - the id of the cell being used by the connected tower\n* `:utc_offset` - the UTC offset in seconds\n* `:location_area_code` - the location area code of a tower\n* `:network_datetime` - the reported datetime of the network when connecting\n* `:roaming` - if you are in roaming or not\n* `:std_offset` - `Calendar.std_offset()` for daylight savings\n  adjustment","ref":"QMI.Codec.NetworkAccess.html#t:serving_system_indication/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.serving_system_registration_state/0","doc":"","ref":"QMI.Codec.NetworkAccess.html#t:serving_system_registration_state/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.set_system_selection_preference_opt/0","doc":"The options to configure the system selection preference\n\n* `:mode_preference` - which radio access technologies should the modem use\n* `:change_duration` - the `preference_change_duration()` for the applied\n  settings. The default is `:permanent`.\n* `:roaming_preference` - the preferred roaming setting","ref":"QMI.Codec.NetworkAccess.html#t:set_system_selection_preference_opt/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.signal_strength_report/0","doc":"Report from requesting the signal strength","ref":"QMI.Codec.NetworkAccess.html#t:signal_strength_report/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.usage_setting_preference/0","doc":"The modem usage preference setting\n\n`:unknown` - device does not know the usage preference setting\n`:voice_centric` - the device is set for voice centric usage\n`:data_centric` - the device is set for data centric","ref":"QMI.Codec.NetworkAccess.html#t:usage_setting_preference/0"},{"type":"type","title":"QMI.Codec.NetworkAccess.voice_domain_preference/0","doc":"The voice domain preference setting\n\n* `:cs_only` - circuit-switched (CS) voice only\n* `:ps_only` - packet-switched (PS) voice only\n* `:cs_preferred` - PS is secondary\n* `:ps_preferred` - CS is secondary","ref":"QMI.Codec.NetworkAccess.html#t:voice_domain_preference/0"},{"type":"module","title":"QMI.Codec.WirelessData","doc":"Codec for making wireless data service requests","ref":"QMI.Codec.WirelessData.html"},{"type":"function","title":"QMI.Codec.WirelessData.modify_profile_settings/2","doc":"Modify the QMI profile setting\n\nWhen providing the profile settings if `:profile_type` is not included this\nfunction will default to `:profile_type_3gpp`","ref":"QMI.Codec.WirelessData.html#modify_profile_settings/2"},{"type":"function","title":"QMI.Codec.WirelessData.parse_event_report_indication/2","doc":"","ref":"QMI.Codec.WirelessData.html#parse_event_report_indication/2"},{"type":"function","title":"QMI.Codec.WirelessData.parse_indication/1","doc":"Try to parse an indication from the wireless data service","ref":"QMI.Codec.WirelessData.html#parse_indication/1"},{"type":"function","title":"QMI.Codec.WirelessData.set_event_report/1","doc":"Request to set the wireless data services event report options","ref":"QMI.Codec.WirelessData.html#set_event_report/1"},{"type":"function","title":"QMI.Codec.WirelessData.start_network_interface/1","doc":"Send command to request the that the network interface starts to receive data","ref":"QMI.Codec.WirelessData.html#start_network_interface/1"},{"type":"function","title":"QMI.Codec.WirelessData.stat_to_integer/1","doc":"","ref":"QMI.Codec.WirelessData.html#stat_to_integer/1"},{"type":"function","title":"QMI.Codec.WirelessData.statistics_mask/1","doc":"","ref":"QMI.Codec.WirelessData.html#statistics_mask/1"},{"type":"type","title":"QMI.Codec.WirelessData.call_end_reason_type/0","doc":"The type of reasons the call ended","ref":"QMI.Codec.WirelessData.html#t:call_end_reason_type/0"},{"type":"type","title":"QMI.Codec.WirelessData.event_report_indication/0","doc":"The indication for the wireless data service's event report\n\nTo configure what information is sent through this indication see\n`set_event_report/1`.","ref":"QMI.Codec.WirelessData.html#t:event_report_indication/0"},{"type":"type","title":"QMI.Codec.WirelessData.event_report_opt/0","doc":"Options for the wireless data event report configuration\n\n* `:statistics_interval` - an interval in seconds on when to report statistics\n  about transmit and receive operations\n* `:statistics` - list which statistic measurements to report\n\nFor transmit and receive statistics, if no interval is provided the default is\n60 seconds. If the `:statistics` option is not provided it will default to\n`:all`. The report is only sent in the interval if there was a change in any\nof the statistics. So, if no changes took place the report will be skipped for\nan interval.\n\nTo configure event report to not included any stats pass `:none` to\nthe `:statistics` option.","ref":"QMI.Codec.WirelessData.html#t:event_report_opt/0"},{"type":"type","title":"QMI.Codec.WirelessData.modify_profile_settings_response/0","doc":"Response from issuing a modify profile settings request","ref":"QMI.Codec.WirelessData.html#t:modify_profile_settings_response/0"},{"type":"type","title":"QMI.Codec.WirelessData.packet_status_indication/0","doc":"The indication for a change in the current packet data connection status","ref":"QMI.Codec.WirelessData.html#t:packet_status_indication/0"},{"type":"type","title":"QMI.Codec.WirelessData.profile_setting/0","doc":"The profile settings\n\n* `:roaming_disallowed` - if using roaming is allowed or not\n* `:profile_type` - the profile type - see `profile_type()` type docs for more\n  information","ref":"QMI.Codec.WirelessData.html#t:profile_setting/0"},{"type":"type","title":"QMI.Codec.WirelessData.profile_type/0","doc":"The profile technology type","ref":"QMI.Codec.WirelessData.html#t:profile_type/0"},{"type":"type","title":"QMI.Codec.WirelessData.start_network_interface_opt/0","doc":"Options for whens starting a network interface\n\n* `:apn` - the name of our APN","ref":"QMI.Codec.WirelessData.html#t:start_network_interface_opt/0"},{"type":"type","title":"QMI.Codec.WirelessData.start_network_report/0","doc":"Report from starting the network interface","ref":"QMI.Codec.WirelessData.html#t:start_network_report/0"},{"type":"type","title":"QMI.Codec.WirelessData.statistic_measurement/0","doc":"The type of measurement you are wanting to be reported\n\n* `:tx_bytes` - number of bytes transmitted\n* `:rx_bytes` - number of bytes received\n* `:tx_packets` - number of transmit packets sent without error\n* `:rx_packets` - number of packets received without error\n* `:tx_overflows` - number of packets dropped due to tx buffer\n  overflowed (out of memory)\n* `:rx_overflows` - number of packets dropped due to rx buffer\n  overflowed (out of memory)\n* `:tx_errors` - number of outgoing packets with framing errors\n* `:rx_errors` - number of incoming packets with framing errors\n* `:tx_drops` - number outgoing packets dropped\n* `:rx_drops` - number incoming packets dropped","ref":"QMI.Codec.WirelessData.html#t:statistic_measurement/0"},{"type":"type","title":"QMI.Codec.WirelessData.tech_name/0","doc":"Name of the technology","ref":"QMI.Codec.WirelessData.html#t:tech_name/0"},{"type":"extras","title":"QMI","doc":"# QMI\n\n[![Hex version](https://img.shields.io/hexpm/v/qmi.svg \"Hex version\")](https://hex.pm/packages/qmi)\n[![API docs](https://img.shields.io/hexpm/v/qmi.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/qmi/QMI.html)\n[![CircleCI](https://circleci.com/gh/nerves-networking/qmi.svg?style=svg)](https://circleci.com/gh/nerves-networking/qmi)\n\nQualcomm MSM Interface in Elixir\n\nThis library lets you send and receive messages from a QMI-enabled cellular\nmodem. It is intended for use with `vintage_net_qmi` and most users will\nwant to use `VintageNet` to configure a cellular modem than to use this\nlibrary directly.","ref":"readme.html"},{"type":"extras","title":"Usage - QMI","doc":"First, start a `QMI.Supervisor` in the supervision tree of your choosing\nand pass it a name and interface. After that, use the service modules to send\nit messages. For example:\n\n```elixir\n# In your application's supervision tree\nchildren = [\n  #... other children ...\n  {QMI.Supervisor, ifname: \"wwan0\", name: MyApp.QMI}\n  #... other children ...\n]\n\n# Later on\niex> QMI.WirelessData.start_network_interface(MyApp.QMI, apn: \"super\")\n:ok\n\niex> QMI.NetworkAccess.get_signal_strength(MyApp.QMI)\n{:ok, %{rssi_reports: [%{radio: :lte, rssi: -74}]}}\n```\n\nIf you are using Linux you will need to call `QMI.configure_linux/1` before\nbring the interface up.","ref":"readme.html#usage"},{"type":"extras","title":"License - QMI","doc":"Copyright (C) 2021 SmartRent\n\n    Licensed under the Apache License, Version 2.0 (the \"License\");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nThis project follows [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [v0.8.6] - 2021-09-08","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"* Fix Elixir and C compilation warnings\n* Improved specs\n\n## [v0.8.5] - 2023-04-01\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fixed incorrect enum value for serving system registration state reports. This\n  could cause crashes if the value 3 (registration denied) was received.\n* Fixed spelling of `:fw_update_discontinuous_frame`\n\n## [v0.8.4] - 2022-04-25\n\n#","ref":"changelog.html#fixes"},{"type":"extras","title":"Added - Changelog","doc":"* `QMI.WirelessData.modify_profile_settings/3` function\n* Can pass 3GPP profile index to `QMI.WirelessData.start_network_interface/2`\n* `:roaming_preference` option to\n  `QMI.NetworkAccess.set_system_selection_preference/2`\n* `QMI.Codec.WirelessData.modify_profile_settings/2` function\n* `QMI.Codec.WirelessData.profile_setting()` type\n* `QMI.Codec.WirelessData.profile_type()` type\n* `:profile_3gpp_index` option\n  `QMI.Codec.WirelessData.start_network_interface_opt()` type\n\n## [v0.8.3] - 2022-02-10\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"Support for getting and setting modem operating mode and support for getting\nand setting configuration for the modem's radio technology preference.\n\n* `QMI.DeviceManagement.get_operating_mode/1` (@jjcarstens)\n* `QMI.DeviceManagement.set_operating_mode/2` (@jjcarstens)\n* `QMI.Codec.DeviceManagement.get_operating_mode/0` (@jjcarstens)\n* `QMI.Codec.DeviceManagement.set_operating_mode/1` (@jjcarstens)\n* `QMI.NetworkAccess.get_system_selection_preference/1`\n* `QMI.NetworkAccess.set_system_selection_preference/2`\n* `QMI.Codec.NetworkAccess.get_system_selection_preference/0`\n* `QMI.Codec.NetworkAccess.set_system_selection_preference/1`\n\n\n## [v0.8.2] - 2021-10-21\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"* Basic parsing of the NAS operator name indication\n\n## [v0.8.1] - 2021-09-21\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixes - Changelog","doc":"* Wrong value for TX/RX stats that have no data to report yet\n* Actually parse TX/RX packets drop count\n\n## [v0.8.0] - 2021-09-21\n\nThis release breaks the type `QMI.Codec.NetworkAccess.rf_band_information()` by\nchanging the `:band` field to a string for a more user friendly description of\nthe current active band.\n\n#","ref":"changelog.html#fixes"},{"type":"extras","title":"Changed - Changelog","doc":"* Changed `QMI.Codec.NetworkAccess.rf_band_information()` field `:band` from\n  `integer()` to `binary()`\n\n## [v0.7.1] - 2021-09-16\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"* `QMI.NetworkAccess.get_rf_band_info/1` to get band and channel information\n* `QMI.WirelessData.set_event_report/2` to configure the wireless data service\n  to report transmit and receive stats\n* Parsing for wireless data service's event report indication\n* `QMI.Codec.WirelessData.set_event_report/1`\n* `QMI.Codec.NetworkAccess.get_rf_band_info/0`\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"* `QMI.request()` decode function type now allows returning `:ok` for request\n  that who's response does not contain any information.\n\n## [v0.7.0] - 2021-09-02\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"* Changed `QMI.Codec.NetworkAccess.serving_system_indication()` time zone\n  fields to match Elixir's `Calendar` module:\n  * `:timezone_offset` is now `:utc_offset`\n  * `:daylight_saving_adjustment` is now `:std_offset`\n\n## [v0.6.5] - 2021-09-01\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"* `:cell_id` to the serving system indication (this is an optional field)\n* `:timezone_offset` to the serving system indication (this is an optional\n  field)\n* `:location_area_code` to the serving system indication (this is an optional\n  field)\n* `:network_datetime` to the serving system indication (this is an optional\n  field)\n* `:roaming` to the serving system indication (this is an optional field)\n* `:network_datetime` to the serving system indication (this is an optional\n  field)\n* `:daylight_saving_adjustment` to the serving system indication (this is an\n  optional field)\n\n## [v0.6.4] - 2021-08-30\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"* `:provider` field to the `QMI.NetworkAccess.get_home_network/1` response\n\n## [v0.6.3] - 2021-08-25\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"* `QMI.DeviceManagement.get_device_serial_numbers/1`\n* Support for Wireless Data Service packet status indication\n\n## [v0.6.2] - 2021-08-20\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"* `QMI.DeviceManagement.get_manufacturer/1`\n* `QMI.DeviceManagement.get_model/1`\n* `QMI.DeviceManagement.get_hardware_rev/1`\n\n## [v0.6.1] - 2021-08-05\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixes - Changelog","doc":"* A crash when a response is received after the request has timed out\n\n## [v0.6.0] - 2021-05-27\n\n#","ref":"changelog.html#fixes"},{"type":"extras","title":"Changed - Changelog","doc":"* `QMI.Codec.Indications` to be an internal module\n\n## [v0.5.1] - 2021-05-25\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"* `QMI.UserIdentity.read_transparent/3`\n* `QMI.UserIdentity.parse_iccid/1`\n* Error reasons returned from sending a request\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixes - Changelog","doc":"* Timeout crash when requesting a new client id\n\n## [v0.5.0] - 2021-05-14\n\n#","ref":"changelog.html#fixes"},{"type":"extras","title":"Added - Changelog","doc":"* Support for QMI indications\n\n## [v0.4.0] - 2021-05-10\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changes - Changelog","doc":"* Supervision tree to support driver crashes (backwards incompatible)\n\n## [v0.3.1] - 2021-04-27\n\n#","ref":"changelog.html#changes"},{"type":"extras","title":"Fixes - Changelog","doc":"* Type spec for `QMI.Codec.NetworkAccess.home_network_report()`\n* Error when the device closes and QMI retries to open the device\n\n## [v0.3.0] - 2021-04-26\n\n#","ref":"changelog.html#fixes"},{"type":"extras","title":"Changes - Changelog","doc":"* Rename `:rssis` to `:rssi_reports` in the\n `QMI.Codec.NetworkAccess.signal_strength_report()`\n\n## [v0.2.0] - 2021-04-16\n\nMajor refactor","ref":"changelog.html#changes"},{"type":"extras","title":"v0.1.0 - 2021-03-17 - Changelog","doc":"Initial release\n\n[v0.8.6]: https://github.com/nerves-networking/qmi/compare/v0.8.5...v0.8.6\n[v0.8.5]: https://github.com/nerves-networking/qmi/compare/v0.8.4...v0.8.5\n[v0.8.4]: https://github.com/nerves-networking/qmi/compare/v0.8.3...v0.8.4\n[v0.8.3]: https://github.com/nerves-networking/qmi/compare/v0.8.2...v0.8.3\n[v0.8.2]: https://github.com/nerves-networking/qmi/compare/v0.8.1...v0.8.2\n[v0.8.1]: https://github.com/nerves-networking/qmi/compare/v0.8.0...v0.8.1\n[v0.8.0]: https://github.com/nerves-networking/qmi/compare/v0.7.1...v0.8.0\n[v0.7.1]: https://github.com/nerves-networking/qmi/compare/v0.7.0...v0.7.1\n[v0.7.0]: https://github.com/nerves-networking/qmi/compare/v0.6.5...v0.7.0\n[v0.6.5]: https://github.com/nerves-networking/qmi/compare/v0.6.4...v0.6.5\n[v0.6.4]: https://github.com/nerves-networking/qmi/compare/v0.6.3...v0.6.4\n[v0.6.3]: https://github.com/nerves-networking/qmi/compare/v0.6.2...v0.6.3\n[v0.6.2]: https://github.com/nerves-networking/qmi/compare/v0.6.1...v0.6.2\n[v0.6.1]: https://github.com/nerves-networking/qmi/compare/v0.6.0...v0.6.1\n[v0.6.0]: https://github.com/nerves-networking/qmi/compare/v0.5.0...v0.6.0\n[v0.5.1]: https://github.com/nerves-networking/qmi/compare/v0.5.0...v0.5.1\n[v0.5.0]: https://github.com/nerves-networking/qmi/compare/v0.4.0...v0.5.0\n[v0.4.0]: https://github.com/nerves-networking/qmi/compare/v0.3.1...v0.4.0\n[v0.3.1]: https://github.com/nerves-networking/qmi/compare/v0.3.0...v0.3.1\n[v0.3.0]: https://github.com/nerves-networking/qmi/compare/v0.2.0...v0.3.0\n[v0.2.0]: https://github.com/nerves-networking/qmi/compare/v0.1.0...v0.2.0","ref":"changelog.html#v0-1-0-2021-03-17"}],"content_type":"text/markdown"}